@@ -1,6 +1,6 @@
-// Copyright 2008-present Contributors to the OpenImageIO project.
-// SPDX-License-Identifier: BSD-3-Clause
-// https://github.com/OpenImageIO/oiio
+// Copyright Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: Apache-2.0
+// https://github.com/AcademySoftwareFoundation/OpenImageIO
 
 // clang-format off
 
@@ -15,6 +15,15 @@
 #include <OpenImageIO/timer.h>
 
 
+#if (((OIIO_GNUC_VERSION && NDEBUG) || OIIO_CLANG_VERSION >= 30500 || OIIO_APPLE_CLANG_VERSION >= 70000 || defined(__INTEL_COMPILER)  || defined(__INTEL_LLVM_COMPILER)) \
+      && (defined(__x86_64__) || defined(__i386__))) \
+    || defined(_MSC_VER)
+#define OIIO_DONOTOPT_FORECINLINE OIIO_FORCEINLINE
+#else
+#define OIIO_DONOTOPT_FORECINLINE inline
+#endif
+
+
 OIIO_NAMESPACE_BEGIN
 
 /// DoNotOptimize(val) is a helper function for timing benchmarks that fools
@@ -23,10 +32,10 @@ OIIO_NAMESPACE_BEGIN
 /// May not work on all platforms. References:
 /// * Chandler Carruth's CppCon 2015 talk
 /// * Folly https://github.com/facebook/folly/blob/master/folly/Benchmark.h
-/// * Google Benchmark https://github.com/google/benchmark/blob/master/include/benchmark/benchmark_api.h
+/// * Google Benchmark https://github.com/google/benchmark/blob/main/include/benchmark/benchmark.h
 
 template <class T>
-OIIO_FORCEINLINE T const& DoNotOptimize (T const &val);
+OIIO_DONOTOPT_FORECINLINE T const& DoNotOptimize (T const &val);
 
 
 /// clobber_all_memory() is a helper function for timing benchmarks that
@@ -120,7 +129,7 @@ OIIO_FORCEINLINE void clobber (T& p, Ts&... ps)
 /// * Beware of the compiler constant folding operations in your code --
 ///   do not pass constants unless you want to benchmark its performance on
 ///   known constants, and it is probably smart to ensure that all variables
-///   acccessed by your code should be passed to clobber() before running
+///   accessed by your code should be passed to clobber() before running
 ///   the benchmark, to confuse the compiler into not assuming its value.
 
 class OIIO_UTIL_API Benchmarker {
